// This module deals with converting the notification object into rson format, which can be used instead of json if preferred
use crate::notification::Notification;
use rson_rs::ser::to_string;
use rson_rs::value::Value;
use rson_rs::value::Value::Map;

impl Notification {
    pub fn actions_rson(&self) -> Value {
        if self.actions().is_empty() {
            Value::from_str("{actions: Null}")
        } else {
            // Wrap the map into a rson_rs::value::Value
            self.actions()
                .iter()
                .map(|(id, label)| {
                    (id.clone(), Value::from_str(label)) // Create key-value pairs: id -> label
                })
                .collect::<Map<_, _>>() // Collect into a rson_rs::value::Value::Map
        }
    }
}
